.ico {
    display: inline-block;
}

.ico:before {
    vertical-align: bottom;
}

.ico-lg {
    font-size: 1.33333333em;
    line-height: 0.45em;
    vertical-align: -15%;
}
.ico-2x {
    font-size: 2em;
}
.ico-3x {
    font-size: 3em;
}
.ico-4x {
    font-size: 4em;
}
.ico-5x {
    font-size: 5em;
}
.ico-fw {
    width: 1.28571429em;
    text-align: center;
}