@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("settings") { @import "settings"; }

// Default Variables

$slick-prev-character: "\e90e" !default;
$slick-next-character: "\e90d" !default;
$slick-dot-size: 6px !default;
$slick-opacity-default: 0.75 !default;
$slick-opacity-on-hover: 1 !default;
$slick-opacity-not-active: 0.35 !default;

/* Slider */

.slick-slider-container {
  padding: 0;
}
.slick-slider {
  overflow: visible;
  position: relative;
}
.slick-slider-slide {
  vertical-align: middle;
}
.slick-slide {
}

.slick-list {
  padding: 0;

  .slick-loading & {
    background: #000;
  }
}

/* Arrows */

.slick-prev,
.slick-next {
  z-index: 10;
  position: absolute;
  display: block;
  height: 45px;
  width: 35px;
  line-height: 0;
  font-size: 0;
  cursor: pointer;
  color: transparent;
  top: 50%;
  -webkit-transform: translate(0, -50%);
  -ms-transform: translate(0, -50%);
  transform: translate(0, -50%);
  padding: 0;
  border: none;
  outline: none;
  opacity: $slick-opacity-default;
  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -ms-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
  &:hover, &:focus {
    outline: none;
    //background: $color-bg-tertiary;
    color: transparent;
    opacity: $slick-opacity-on-hover;
    &:before {
      //color: $color-text-invert;
    }
  }
  &.slick-disabled {
    opacity: $slick-opacity-not-active;
  }
  &:before {
    @include iconfont;
    line-height: 45px;
    color: $color-text;
    text-shadow: 0 0 5px #000;
    font-size: 30px;
    position: relative;
    -webkit-transition: all .75s cubic-bezier(0,0,0,1);
    -moz-transition: all .75s cubic-bezier(0,0,0,1);
    -ms-transition: all .75s cubic-bezier(0,0,0,1);
    -o-transition: all .75s cubic-bezier(0,0,0,1);
    transition: all .75s cubic-bezier(0,0,0,1);
  }
}

.slick-prev {
  left: 15px;
  [dir="rtl"] & {
    left: auto;
    right: 15px;
  }
  &:before {
    left: 0;
    content: $slick-prev-character;
    [dir="rtl"] & {
      left: auto;
      right: 0;
      content: $slick-next-character;
    }
  }
  &:hover {
    &:before {
      left: -5px;
    }
  }
  [dir="rtl"] & {
    &:hover {
      &:before {
        right: -5px;
      }
    }
  }
}

.slick-next {
  right: 15px;
  [dir="rtl"] & {
    left: 15px;
    right: auto;
  }
  &:before {
    right: 0;
    content: $slick-next-character;
    [dir="rtl"] & {
      right: auto;
      left: 0;
      content: $slick-prev-character;
    }
  }
  &:hover {
    &:before {
      right: -5px;
    }
  }
  [dir="rtl"] & {
    &:hover {
      &:before {
        left: -5px;
      }
    }
  }
}

/* Dots */

.slick-dotted.slick-slider {
  margin-bottom: 30px;
}

.slick-dots {
  position: absolute;
  top: 100%;
  list-style: none;
  display: block;
  text-align: center;
  padding: 0;
  margin: 0;
  width: 100%;
  line-height: 30px;
  li {
    position: relative;
    display: inline-block;
    vertical-align: middle;
    height: 12px;
    width: 12px;
    margin: 0 5px;
    padding: 0;
    cursor: pointer;
    button {
      border: 0;
      background: $color-bg-secondary;
      display: block;
      height: 12px;
      width: 12px;
      outline: none;
      line-height: 0px;
      font-size: 0px;
      color: transparent;
      padding: 5px;
      cursor: pointer;
      -webkit-border-radius: 99px;
      -moz-border-radius: 99px;
      border-radius: 99px;
      &:hover, &:focus {
        outline: none;
      }
    }
    &.slick-active button {
      background: $color-bg-tertiary;
    }
  }
}
