@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("framework") { @import "framework"; }

/*
 ------ CONTENT ------
*/
#container {
  padding: 0;
  position: relative;
  z-index: 1;
  background: $color-bg-primary;
}

#main {
  @include box-sizing(border-box);

  .mod_article {
    //padding: 20px 0;

    &:first-child:not(.alternate) {
      padding-top: 0;
    }
    &:last-child:not(.alternate) {
      padding-bottom: 0;
    }
    
    &.alternate {
      background-color: $color-bg-senary;
      padding-left: 80px;
      padding-right: 80px;

      &:first-child {
        //margin-top: -20px;
      }

      &:last-child {
        margin-bottom: -20px;
      }

      @include for-tablet {
        padding-left: 40px;
        padding-right: 40px;
      }

      @include for-mobile {
        padding-left: 20px;
        padding-right: 20px;
      }
    }
  }
}

#breadcrumb {
  @include centered-1200;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  /*position: absolute;
  top: 14px;
  left: 0;
  right: 0;*/
  margin: -46px auto 19px;
  font-size: font-size(14px);
  line-height: 1;
  padding: 0 0 5px;
  color: $color-text-breadcrumb;
  border-bottom: 1px $color-stroke-grey solid;
  ul {
    margin: 0;
    padding: 0;
    //white-space: nowrap;
  }

  li {
    display: inline-block;
    line-height: 1.5;
    margin-right: 1px;

    &:before {
      @include iconfont;
      font-size: inherit;
      display: inline-block;
      line-height: inherit;
      margin-right: 2px;
      content: "\e907";
      vertical-align: -0.1em;
    }

    &:first-child {
      &:before {
        display: none;
      }
    }

    a {
      display: inline;
    }
  }
}

