<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */

$GLOBALS['TL_LANG']['REF']['divisions']['management'] = 'Geschäftsführung / Vetrieb';
$GLOBALS['TL_LANG']['REF']['divisions']['representatives'] = 'Aussendienst';
$GLOBALS['TL_LANG']['REF']['divisions']['office'] = 'Telefonverkauf / Büro';
$GLOBALS['TL_LANG']['REF']['divisions']['sales'] = 'Verkauf';
$GLOBALS['TL_LANG']['REF']['divisions']['administration'] = 'Sekretariat';
$GLOBALS['TL_LANG']['REF']['divisions']['accounting'] = 'Buchhaltung';
$GLOBALS['TL_LANG']['REF']['divisions']['tasting'] = 'Weinprobe';
$GLOBALS['TL_LANG']['REF']['divisions']['warehouse'] = 'Lager / Versand';
$GLOBALS['TL_LANG']['REF']['divisions']['bottling'] = 'Abfülltechnik';
$GLOBALS['TL_LANG']['REF']['divisions']['cellar'] = 'Kellertechnik';
$GLOBALS['TL_LANG']['REF']['divisions']['logistics'] = 'Zustellung';
$GLOBALS['TL_LANG']['REF']['divisions']['spirits'] = 'Edelbrände';
$GLOBALS['TL_LANG']['REF']['divisions']['facility_management'] = 'Reinigung';
$GLOBALS['TL_LANG']['REF']['divisions']['marketing'] = 'Marketing';

$GLOBALS['TL_LANG']['MSC']['divisions_filter'] = 'Abteilung:';
