<?php

/**
 * JustifiedGallery for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */


/**
 * Asset version
 */
$GLOBALS['TL_ASSETS']['TEAMLIST_QUICKSAND'] = '1.4';

/**
 * Backend modules
 */

$GLOBALS['BE_MOD']['content']['eSM_team'] = array
(
    'tables'   => array('tl_eSM_team_group','tl_eSM_team'),
    'icon'     => 'system/modules/eSM_team/html/icon.png',
);

/**
 * Frontend modules
 */

$GLOBALS['FE_MOD']['team']['teamlist'] = 'ModuleTeam';

/**
 * Divisions
 */

$GLOBALS['eSM_team']['divisions'] = array
(
    'management',
    'representatives',
    'office',
    'sales',
    'administration',
    'accounting',
    'tasting',
    'warehouse',
    'bottling',
    'cellar',
    'logistics',
    'spirits',
    'facility_management',
    'marketing'
);